Dataclasses
===========

.. automodule:: iceprod.core.dataclasses
   :no-members:
   :no-undoc-members:

Configuration Objects
---------------------

The building blocks of how datasets, jobs, and tasks are configured.

.. autoclass:: Job 
   :members:

.. autoclass:: Steering

.. autoclass:: _TaskCommon

.. autoclass:: Task 
   :show-inheritance:

.. autoclass:: Tray 
   :show-inheritance:

.. autoclass:: Module
   :show-inheritance:

.. autoclass:: Class

.. autoclass:: _ResourceCommon

.. autoclass:: Resource
   :show-inheritance:

.. autoclass:: Data
   :show-inheritance:

Metadata Objects
----------------

Metadata for NSF requirements

.. autoclass:: DifPlus

.. autoclass:: Dif

.. autoclass:: Plus

.. autoclass:: Personnel

.. autoclass:: DataCenter

